@@ -6,7 +6,7 @@ use Perl::PrereqScanner::NotQuiteLite 0.9901;
 use List::Util 1.33 qw/none/;
 use version;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 $VERSION =~ s/_//; ## no critic
 
 # These equivalents should be reasonably well-known and, preferably,
@@ -29,6 +29,7 @@ our @STRICT_WARNINGS_EQUIV = qw(
   Moose::Util::TypeConstraints Moose::Util::MetaRole
   MooseX::Declare MooseX::Role::Parameterized MooseX::Types
   Mouse Mouse::Role
+  Object::Pad
   perl5 perl5i::1 perl5i::2 perl5i::latest
   Pegex::Base
   Role::Tiny
@@ -228,6 +229,7 @@ sub kwalitee_indicators {
                 my $d = shift;
                 my $files = $d->{files_hash} || {};
 
+                my $perl_version_with_implicit_use_warnings = version->new('5.036')->numify;
                 my @no_warnings;
                 for my $file (keys %$files) {
                     next unless exists $files->{$file}{module};
@@ -236,6 +238,11 @@ sub kwalitee_indicators {
                     next if $file =~ /\.pod$/;
                     my $module = $files->{$file}{module};
                     my $requires = $files->{$file}{requires} || {};
+                    my $required_perl = $requires->{perl};
+                    if (defined $required_perl) {
+                        $required_perl =~ s/_//;  # tweak 5.008_001 and the likes for silence
+                        next if version->parse($required_perl)->numify >= $perl_version_with_implicit_use_warnings;
+                    }
                     push @no_warnings, $module if none {exists $requires->{$_}} (@WARNINGS_EQUIV, @STRICT_WARNINGS_EQUIV);
                 }
                 if (@no_warnings) {
